@@ -10,6 +10,9 @@ would appreciate credit if this program or parts of it are used.
 #include "expect_cf.h"
 #include <stdio.h>
 #include <setjmp.h>
+#ifdef HAVE_INTTYPES_H
+#  include <inttypes.h>
+#endif
 #include <sys/types.h>
 #include <sys/ioctl.h>
 
