@@ -30,7 +30,7 @@ would appreciate credit if this program or parts of it are used.
 #include "exp_log.h"
 
 #ifdef TCL_DEBUGGER
-#include "Dbg.h"
+#include "tcldbg.h"
 #endif
 
 #define NO_SIG 0
