@@ -42,6 +42,9 @@ extern char *TclGetRegError();
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
 #endif
+#ifdef HAVE_INTTYPES_H
+#  include <inttypes.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -366,7 +369,13 @@ getptymaster()
 #else
 	if ((master = open("/dev/ptmx", O_RDWR)) == -1) return(-1);
 #endif
-	if ((slave_name = (char *)ptsname(master)) == NULL || unlockpt(master) || grantpt(master)) {
+	if ((slave_name = (char *)ptsname(master)) == NULL || unlockpt(master)) {
+		close(master);
+		return(-1);
+	} else if (grantpt(master)) {
+		static char buf[500];
+		exp_pty_error = buf;
+		sprintf(exp_pty_error,"grantpt(%d) failed - likely reason is that your system administrator (in a rage of blind passion to rid the system of security holes) removed setuid from the utility used internally by grantpt to change pty permissions.  Tell your system admin to reestablish setuid on the utility.  Get the utility name by running Expect under truss or trace.");
 		close(master);
 		return(-1);
 	}
